/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://java.net/hg/bluebill-mobile~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.taxonomy.factsheet.impl.sound;

import javax.annotation.Nonnull;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import it.tidalwave.util.AsException;
import it.tidalwave.observation.Observation;
import it.tidalwave.bluebill.mobile.taxonomy.factsheet.ui.sound.TaxonSoundFactSheetView;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import static org.openide.util.NbBundle.*;
import static it.tidalwave.role.Identifiable.Identifiable;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Slf4j @RequiredArgsConstructor @SuppressWarnings("serial")
public class OpenWebPageAction extends AbstractAction
  {
    private static final Class<OpenWebPageAction> _ = OpenWebPageAction.class;

    @Nonnull
    private final Observation observation;
    
    @Nonnull
    private final TaxonSoundFactSheetView view;

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
      {
        putValue(NAME, getMessage(_, "openMediaWebPage"));
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public void actionPerformed (final @Nonnull ActionEvent event)
      {
        try
          {
            log.info("actionPerformed({}) - media: {}", event, observation);        
            view.openWebPage(observation.as(Identifiable).getId().stringValue());
          }
        catch (Exception e)
          {
            log.warn("Can't open web page {}", e);
            log.warn("", e);
            // FIXME: non fatal notification to the view
          }
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    @Override
    public boolean isEnabled() 
      {
        try
          {
            observation.as(Identifiable).getId(); // to probe existence of id
            return true;
          }
        catch (AsException e)
          {
            return false;
          }
      }
  }
